@@ -3,13 +3,21 @@
 
 #include <Rcpp.h>
 #include <libxml/tree.h>
-#include <boost/shared_ptr.hpp>
 #include <map>
 
-inline xmlChar* asXmlChar(std::string x) {
-  return (xmlChar*) x.c_str();
+inline const xmlChar* asXmlChar(std::string const& x) {
+  return (const xmlChar*) x.c_str();
 }
 
+inline const xmlChar* asXmlChar(SEXP x, int n = 0) {
+  return (const xmlChar*) CHAR(STRING_ELT(x, n));
+}
+
+// If we are using C++11 disallow moves
+#if __cplusplus >= 201103L
+void asXmlChar(std::string&&) = delete;
+#endif
+
 inline Rcpp::CharacterVector asCharacterVector(std::string x) {
   return Rcpp::CharacterVector(Rf_mkCharCE(x.c_str(), CE_UTF8));
 }
